pub struct BatchCreateBody {
pub input_file_id: String,
pub endpoint: BatchEndpoint,
pub auto_delete_input_file: Option<bool>,
pub metadata: Option<BTreeMap<String, String>>,
}Expand description
Request body for creating a batch task
Fields
input_file_id: StringID of the uploaded .jsonl file (purpose must be “batch”)
endpoint: BatchEndpointEndpoint to be used for all requests in the batch
auto_delete_input_file: Option<bool>Whether to auto delete input file after processing (default: true)
metadata: Option<BTreeMap<String, String>>String metadata for task management and tracking (up to 16 key-value pairs).
Implementations
Sourceimpl BatchCreateBody
impl BatchCreateBody
Sourcepub fn new(input_file_id: impl Into<String>, endpoint: BatchEndpoint) -> Self
pub fn new(input_file_id: impl Into<String>, endpoint: BatchEndpoint) -> Self
Create a new batch body from an input file id and target endpoint
(auto-delete defaults to true).
Sourcepub fn with_auto_delete_input_file(self, v: bool) -> Self
pub fn with_auto_delete_input_file(self, v: bool) -> Self
Set auto delete flag
Sourcepub fn with_metadata(self, v: BTreeMap<String, String>) -> Self
pub fn with_metadata(self, v: BTreeMap<String, String>) -> Self
Set string metadata.