ImageGenRequest

Struct ImageGenRequest 

pub struct ImageGenRequest<N>{
    pub key: String,
    /* private fields */
}
Image generation request structure Provides a typed builder around the image generation API body

Fields

key: String

API key for authentication

Implementations

Source

impl<N> ImageGenRequest<N>

pub fn new(model: N, key: String) -> Self

Create a new image generation request for the given model and API key

pub fn body_mut(&mut self) -> &mut ImageGenBody<N>

Mutable access to inner body (for advanced customizations)

pub fn with_prompt(self, prompt: impl Into<String>) -> Self

Set prompt text

pub fn with_quality(self, quality: ImageQuality) -> Self

Set image quality

pub fn with_size(self, size: ImageSize) -> Self

Set image size

pub fn with_watermark_enabled(self, watermark_enabled: bool) -> Self

Enable/disable watermark

pub fn with_user_id(self, user_id: impl Into<String>) -> Self

Set user id

pub fn validate(&self) -> ZaiResult<()>

pub async fn send(&self) -> ZaiResult<ImageResponse>