OcrLanguageType

Enum OcrLanguageType 

pub enum OcrLanguageType {
Show 25 variants Auto, ChnEng, Eng, Jap, Kor, Fre, Spa, Por, Ger, Ita, Rus, Dan, Dut, Mal, Swe, Ind, Pol, Rom, Tur, Gre, Hun, Tha, Vie, Ara, Hin,
}
Language types for OCR recognition

Variants



Auto

Auto-detect language



ChnEng

Chinese and English (default)



Eng

English



Jap

Japanese



Kor

Korean



Fre

French



Spa

Spanish



Por

Portuguese



Ger

German



Ita

Italian



Rus

Russian



Dan

Danish



Dut

Dutch



Mal

Malay



Swe

Swedish



Ind

Indonesian



Pol

Polish



Rom

Romanian



Tur

Turkish



Gre

Greek



Hun

Hungarian



Tha

Thai



Vie

Vietnamese



Ara

Arabic



Hin

Hindi