TextToAudio

Trait TextToAudio 

pub trait TextToAudio { }
Indicates that a model supports text-to-speech synthesis.

Models implementing this trait can convert text input to audio output, supporting various voices and audio formats.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors