pub struct RealtimeAudioChunk {
pub response_id: String,
pub item_id: String,
pub output_index: Option<u64>,
pub content_index: Option<u64>,
pub data: Bytes,
}Available on crate feature
realtime only.Expand description
One decoded response.audio.delta payload with its correlation metadata.
Fields
response_id: StringId of the response this audio belongs to.
item_id: StringId of the output item this audio belongs to.
output_index: Option<u64>Index of the output item within the response, when supplied.
content_index: Option<u64>Index of the content part within the output item, when supplied.
data: BytesDecoded raw 24 kHz, mono, 16-bit PCM bytes.