RealtimeModel

Trait RealtimeModel 

pub trait RealtimeModel: ModelName + Sealed { }
Available on crate feature realtime only.
Marker trait for model ids usable in a realtime session.

This trait is sealed and implemented only for the current official realtime model ids, so arbitrary or retired model markers cannot reach session construction.

use zai_rs::{model::GLM4_voice, realtime::RealtimeClient};

let client = RealtimeClient::new("abc.secret-value");
// `GLM4_voice` is an HTTP voice-chat model, not a Realtime WebSocket model.
let _session = client.session(GLM4_voice {});

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors