ApplicationFileUploadRequest

Struct ApplicationFileUploadRequest 

pub struct ApplicationFileUploadRequest {
    pub app_id: String,
    pub files: Vec<(String, Vec<u8>)>,
    pub upload_unit_id: Option<String>,
    pub conversation_id: Option<String>,
    pub file_type: Option<i64>,
}
Multipart request for uploading one or more application files.

Fields

app_id: String

Application identifier (required multipart field app_id).

files: Vec<(String, Vec<u8>)>

Files represented as (filename, bytes) pairs. Each file is encoded as a separate multipart field named files.

upload_unit_id: Option<String>

Upload component identifier for text applications.

conversation_id: Option<String>

Conversation identifier for temporary conversation files.

file_type: Option<i64>

Upstream numeric file type (1 through 5 are currently documented).

Implementations

Source

impl ApplicationFileUploadRequest

pub fn new(app_id: impl Into<String>, files: Vec<(String, Vec<u8>)>) -> Self

Create an upload request with the required application and files.

pub fn with_upload_unit_id(self, upload_unit_id: impl Into<String>) -> Self

Set the upload component identifier.

pub fn with_conversation_id(self, conversation_id: impl Into<String>) -> Self

Set the conversation identifier for temporary files.

pub fn with_file_type(self, file_type: i64) -> Self

Set the upstream numeric file type.

pub fn validate(&self) -> ZaiResult<()>

Validate the required repeated binary field before allocating a body.

pub async fn send_via( &self, client: &ZaiClient, ) -> ZaiResult<ApplicationFileUploadResponse>

Send the multipart request through client.