pub struct ApplicationInvokeContent {
pub type_: String,
pub value: String,
pub key: Option<String>,
}Expand description
One typed content value in an application invocation message.
Fields
type_: StringUpstream content type, for example input or upload_file.
value: StringText, selection, file identifier, or media URL.
key: Option<String>Field name, required by the service for text applications.
Implementations