pub enum ContentSize {
Medium,
High,
}Expand description
Content size options for search results
Variants
Medium
Medium content size with summary information for basic reasoning needs
High
High content size with maximized context and detailed information