pub struct ToolMetadata { /* private fields */ }Expand description
Metadata used to identify, describe, and categorize a tool.
Implementations
Sourceimpl ToolMetadata
impl ToolMetadata
Sourcepub fn new(
name: impl Into<String>,
description: impl Into<String>,
) -> ToolResult<Self>
pub fn new( name: impl Into<String>, description: impl Into<String>, ) -> ToolResult<Self>
Create new metadata with validation
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Human-readable description presented to the model.
Optional tool author.
Category tags attached to the tool.
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Whether the executor may run and export this tool.
Sourcepub fn additional_metadata(&self) -> &HashMap<Cow<'static, str>, Value>
pub fn additional_metadata(&self) -> &HashMap<Cow<'static, str>, Value>
Additional application-defined metadata.
Sourcepub fn with_version(self, version: impl Into<Cow<'static, str>>) -> Self
pub fn with_version(self, version: impl Into<Cow<'static, str>>) -> Self
Set the tool version.
Set the tool author.
Set the tool’s category tags.
Sourcepub fn with_enabled(self, enabled: bool) -> Self
pub fn with_enabled(self, enabled: bool) -> Self
Enable or disable the tool.