pub async fn query(client: &ZaiClient) -> ZaiResult<CodingPlanUsageResponse>Expand description
Query the Coding Plan usage endpoint via client and return the typed raw
response.
pub async fn query(client: &ZaiClient) -> ZaiResult<CodingPlanUsageResponse>Query the Coding Plan usage endpoint via client and return the typed raw
response.