pub struct ImageGenRequest<N>{
pub key: String,
/* private fields */
}Expand description
Image generation request structure Provides a typed builder around the image generation API body
Fields
key: StringAPI key for authentication
Implementations
Sourceimpl<N> ImageGenRequest<N>
impl<N> ImageGenRequest<N>
Sourcepub fn new(model: N, key: String) -> Self
pub fn new(model: N, key: String) -> Self
Create a new image generation request for the given model and API key
Sourcepub fn body_mut(&mut self) -> &mut ImageGenBody<N>
pub fn body_mut(&mut self) -> &mut ImageGenBody<N>
Mutable access to inner body (for advanced customizations)
Sourcepub fn with_prompt(self, prompt: impl Into<String>) -> Self
pub fn with_prompt(self, prompt: impl Into<String>) -> Self
Set prompt text
Sourcepub fn with_quality(self, quality: ImageQuality) -> Self
pub fn with_quality(self, quality: ImageQuality) -> Self
Set image quality
Sourcepub fn with_watermark_enabled(self, watermark_enabled: bool) -> Self
pub fn with_watermark_enabled(self, watermark_enabled: bool) -> Self
Enable/disable watermark
Sourcepub fn with_user_id(self, user_id: impl Into<String>) -> Self
pub fn with_user_id(self, user_id: impl Into<String>) -> Self
Set user id
pub fn validate(&self) -> ZaiResult<()>
pub async fn send(&self) -> ZaiResult<ImageResponse>