ToolExecutor

Struct ToolExecutor 

pub struct ToolExecutor { /* private fields */ }
Enhanced tool executor with built-in registry and fluent API

Implementations

Source

impl ToolExecutor

pub fn new() -> Self

Create a new executor with default config

pub fn builder() -> ExecutorBuilder

Create an executor builder for fluent API

pub fn with_cache_enabled(self, enabled: bool) -> Self

Enable or disable tool call result caching

pub fn with_cache_ttl(self, ttl: Duration) -> Self

Set cache TTL (time-to-live)

pub fn with_cache_max_size(self, size: usize) -> Self

Set maximum cache size

pub fn clear_cache(&self)

Clear the cache

pub fn invalidate_cache_for_tool(&self, tool_name: &str)

Invalidate cache for a specific tool

pub fn cache_stats(&self) -> CacheStats

Get cache statistics

pub fn add_dyn_tool(&self, tool: Box<dyn DynTool>) -> &Self

Chain-friendly: add a dynamic tool (panics on error)

pub fn try_add_dyn_tool(&self, tool: Box<dyn DynTool>) -> &Self

Chain-friendly: try to add a dynamic tool (ignores error)

pub fn unregister(&self, name: &str) -> ToolResult<()>

Unregister a tool

pub fn input_schema(&self, name: &str) -> Option<Value>

Get input schema for a tool

pub fn has_tool(&self, name: &str) -> bool

Check if tool exists

pub fn tool_names(&self) -> Vec<String>

List tool names

pub async fn execute( &self, tool_name: &str, input: Value, ) -> ToolResult<ExecutionResult>

Execute a tool with detailed result and exponential backoff

pub async fn execute_simple( &self, tool_name: &str, input: Value, ) -> ToolResult<Value>

Execute a tool and return only the result

pub fn add_functions_from_dir_with_registry( &self, dir: impl AsRef<Path>, handlers: &HashMap<String, Arc<dyn Fn(Value) -> Pin<Box<dyn Future<Output = ToolResult<Value>> + Send>> + Send + Sync>>, strict: bool, ) -> ToolResult<Vec<String>>

Bulk load function specs from a directory of .json files and register them with handlers.

  • Each file should contain either of the following shapes:
    1. {“name”:…, “description”:…, “parameters”: {…}}
    2. {“type”:“function”, “function”: {“name”:…, “description”:…, “parameters”: {…}}}
  • handlers maps function name -> handler closure
  • strict: when true, missing handler for any spec will return error; when false, specs without handlers are skipped

Returns the list of function names successfully registered.

pub async fn execute_tool_calls_parallel( &self, calls: &[ToolCallMessage], ) -> Vec<TextMessage>

pub async fn execute_tool_calls_ordered( &self, calls: &[ToolCallMessage], ) -> Vec<TextMessage>

Execute LLM tool_calls in parallel with result ordering preserved

This method guarantees that results are returned in the same order as the input calls, which is important for maintaining conversation context in LLM interactions.

Behavior:

  • Parses each ToolCallMessage’s function.arguments (stringified JSON supported)
  • Runs all tools concurrently using this executor
  • Preserves the original order of tool calls in results
  • Captures errors per-call and encodes them as JSON
  • Preserves tool_call id by emitting TextMessage::tool_with_id when present

Returns:

  • Vec in the same order as input calls, ready for ChatCompletion
pub fn export_tool_as_function(&self, name: &str) -> Option<Tools>

Export a single registered tool as Tools::Function (for LLM function calling)

pub fn export_all_tools_as_functions(&self) -> Vec<Tools>

Export all registered tools as a VecTools::Function

pub fn export_tools_filtered<F>(&self, filter: F) -> Vec<Tools>
where F: FnMut(&ToolMetadata) -> bool,

Export all registered tools with a metadata filter as Tools::Function

pub fn config(&self) -> &ExecutionConfig

Get the config