pub async fn query(key: impl Into<String>) -> ZaiResult<CodingPlanUsageResponse>Expand description
Query the Coding Plan usage endpoint and return the typed raw response.
pub async fn query(key: impl Into<String>) -> ZaiResult<CodingPlanUsageResponse>Query the Coding Plan usage endpoint and return the typed raw response.